/** @file

Lambert2 class implementation

Copyright (C) 2002-2005   The Board of Trustees of The Leland
Stanford Junior University.  All Rights Reserved.

$Id: Lambert2.cxx,v 1.1 2007/03/14 23:28:29 xiefang Exp $

*/

#include "Lambert2.h"
#include "UnaryTransform.h"

using namespace hippodraw;


Lambert2::Lambert2 ( UnaryTransform * z )
  : PeriodicBinaryTransform ( z, true, true, false, true,
			      0.0, +360.0,
			      - 90.0, + 90.0 )
{
  m_name = "Lambert2";
  const std::string projType("ZEA");
  double crpix[] = {180, 0}, crval[] = {180,90}, cdelt[] = {1, 1};
  initwcs (projType, crpix, crval, cdelt, 0, false);
}

Lambert2::Lambert2 ( const Lambert2 & t )
  :  PeriodicBinaryTransform ( t )
{
  const std::string projType("ZEA");
  double crpix[] = {180, 0}, crval[] = {180,90}, cdelt[] = {1, 1};
  initwcs (projType, crpix, crval, cdelt, 0, false);
}

Lambert2::~Lambert2 ()
{
}

#ifdef CLONE_DEFECT
TransformBase * Lambert2::clone () const
#else
Lambert2    * Lambert2::clone () const
#endif
{
  return new Lambert2 ( *this );
}



/* virtual */
double Lambert2::aspectRatio () const
{
  return 1.0;
}



